package de.hdm_stuttgart.mi.sd1.task1;

/**
 * <p>Methods checking lists of values for sub patterns.</p>
 */
public class _2_SubSequence {

    /**
     * <p>A fixed value indicating the absence of a sub sequence within a given list of values.</p>
     *
     * <p>See {@link #getFirstIndexOf_123(int[])} and {@link #getFirstIndexOf(int[], int[])} for details.</p>
     */
    static public final int NOT_PRESENT_INDEX = -1;

    /**
     * <p>Check a list of values for the presence of the fixed sub sequence {1, 2, 3}.</p>
     *
     * <table class="goikTableDefaults">
     *     <caption>Examples</caption>
     *     <tbody>
     *         <tr>
     *             <th>Values</th>
     *             <th>Returned index</th>
     *         </tr>
     *
     *         <tr>
     *             <td>
     *               <table class='indexTable'>
     *                   <caption>{-5, 7, <em class='myRed'>1, 2, 3</em>, 0}<br><br></caption>
     *                 <tbody>
     *                   <tr>
     *                     <th>Value:</th>
     *                     <td>-5</td>
     *                     <td>7</td>
     *                     <td class='myRed'>1</td>
     *                     <td class='myRed'>2</td>
     *                     <td class='myRed'>3</td>
     *                     <td>0</td>
     *                   </tr>
     *                   <tr>
     *                     <th>Index:</th>
     *                     <td>0</td>
     *                     <td>1</td>
     *                     <td class='myGreen'>2</td>
     *                     <td>3</td>
     *                     <td>4</td>
     *                     <td>5</td>
     *                   </tr>
     *                 </tbody>
     *               </table>
     *             </td>
     *             <td>Index <code class='myGreen'>2</code> corresponding to first value
     *                <code class='myRed'>1</code> of matching sequence
     *                <code class='myRed'>{1, 2, 3}</code>
     *           </td>
     *         </tr>
     *
     *         <tr>
     *             <td>{4, 3, 1, 5, 9}</td>
     *             <td>No sequence {1, 2, 3} present, returning {@link #NOT_PRESENT_INDEX}.</td>
     *         </tr>
     *         <tr>
     *             <td>{}</td>
     *             <td>There is no reasonable index value being applicable to an empty list thus
     *                   returning {@link #NOT_PRESENT_INDEX}.</td>
     *         </tr>
     *     </tbody>
     * </table>
     *
     * @param values An list of values.
     * @return The index value corresponding to the value 1 of the first detected sequence {1, 2, 3} being contained in
     * values. {@link #NOT_PRESENT_INDEX} if no such sequence is present.
     */
    static public int getFirstIndexOf_123(final int[] values) {

        return 42; // TODO: implement me correctly
    }

    /**
     * <p>Check a list of values for the presence of a sub sequence.</p>
     * <p>This method generalizes {@link #getFirstIndexOf_123(int[])} by searching for an arbitrary sequence
     * rather than just fixed {1, 2, 3}.</p>
     *
     * <table class="goikTableDefaults">
     *     <caption>Examples</caption>
     *     <tbody>
     *         <tr>
     *             <th>Values</th>
     *             <th>Sub sequence</th>
     *             <th>Returned index</th>
     *         </tr>
     *
     *         <tr>
     *             <td>
     *               <table class='indexTable'>
     *                   <caption>{0, -5, 7, <em class='myRed'>6, -1, 4</em>, 0}<br><br></caption>
     *                 <tbody>
     *                   <tr>
     *                     <th>Value:</th>
     *                     <td>0</td>
     *                     <td>-5</td>
     *                     <td>7</td>
     *                     <td class='myRed'>6</td>
     *                     <td class='myRed'>-1</td>
     *                     <td class='myRed'>4</td>
     *                     <td>0</td>
     *                   </tr>
     *                   <tr>
     *                     <th>Index:</th>
     *                     <td>0</td>
     *                     <td>1</td>
     *                     <td>2</td>
     *                     <td class='myGreen'>3</td>
     *                     <td>4</td>
     *                     <td>5</td>
     *                     <td>6</td>
     *                   </tr>
     *                 </tbody>
     *               </table>
     *             </td>
     *             <td>{<em class='myRed'>6, -1, 4</em>}</td>
     *             <td>Index <code class='myGreen'>3</code> corresponding to first value
     *                <code class='myRed'>6</code> of matching sequence
     *                <code class='myRed'>{6, -1, 4}</code>
     *           </td>
     *         </tr>
     *
     *         <tr>
     *             <td>{4, 3, 1, 5, 9}</td>
     *             <td><em class='myRed'>{2, 3}</em></td>
     *             <td>No sequence <em class='myRed'>{2, 3}</em> present thus
     *             returning {@link #NOT_PRESENT_INDEX}.</td>
     *         </tr>
     *         <tr>
     *             <td>{2, 2, 4, 5}</td>
     *             <td><em class='myRed'>{}</em></td>
     *             <td>An empty sequence is always being contained in any non-empty list thus returning
     *             starting index 0.</td>
     *         </tr>
     *         <tr>
     *             <td>{}</td>
     *             <td>Arbitrary sequence</td>
     *             <td>There is no reasonable index value being applicable to an empty list thus
     *             returning {@link #NOT_PRESENT_INDEX}.</td>
     *         </tr>
     *     </tbody>
     * </table>
     *
     * @param values      A list of values
     * @param subSequence A sequence of values possibly being contained within the given list.
     * @return <p>Either of:</p>
     *          <ul>
     *              <li>
     *                  <p>The starting index of the first <code>subSequence</code> appearing
     *                        in <code>values</code>.</p>
     *
     *                  <p><em>Note:</em> An empty <code>subSequence</code> is always being contained
     *                  within any non-empty list thus returning the 0 index.</p>
     *               </li>
     *
     *              <li>
     *                  <p>{@link #NOT_PRESENT_INDEX} if no such sequence is present.</p>
     *
     *                  <p><em>Note:</em> An empty <code>values</code>
     *                     list cannot be accessed by any index thus resulting in {@link #NOT_PRESENT_INDEX}.</p>
     *              </li>
     *          </ul>
     *
     */
    static public int getFirstIndexOf(final int[] values, final int[] subSequence) {
        return 42; // TODO: implement me correctly
    }
}
