package de.hdm_stuttgart.mi.sd1.task2;

/**
 * <p>Converting between different length units.</p>
 *
 * <p>Lengths are being measured in different units all over the world. This class considers the following units
 * among with their respective conversions to meter:</p>
 *
 * <table class="goikTableDefaults">
 *     <caption>Metric and Imperial unit definitions</caption>
 *     <tbody>
 *         <tr>
 *             <th>Name</th>
 *             <th>Enum definition</th>
 *             <th>Length in meter</th>
 *         </tr>
 *         <tr>
 *             <td>Meter (m)</td>
 *             <td>{@link Unit#METER}</td>
 *             <td>1.0</td>
 *         </tr>
 *         <tr>
 *             <td>Inch</td>
 *             <td>{@link Unit#INCH}</td>
 *             <td>0.0254</td>
 *         </tr>
 *         <tr>
 *             <td>Imperial mile</td>
 *             <td>{@link Unit#MILE_IMPERIAL}</td>
 *             <td>1609.344</td>
 *         </tr>
 *         <tr>
 *             <td>Nautical mile</td>
 *             <td>{@link Unit#MILE_NAUTICAL}</td>
 *             <td>1852.0</td>
 *         </tr>
 *
 *     </tbody>
 * </table>
 *
 * <p>The following samples illustrate conversions between different units:</p>
 *
 * <table class="goikTableDefaults">
 *     <caption>Sample code illustrating unit conversions</caption>
 *     <tbody>
 *         <tr>
 *             <th>Code</th>
 *             <th>Result</th>
 *         </tr>
 *         <tr>
 *             <td>
 *                 <pre><code class="java"> final LengthUnitCalculator c =
 *      new LengthUnitCalculator();                            // Default unit meter.
 *
 * System.out.println("Turning meter into nautical miles");
 * c.setLength(1852);                                          // Setting length 1852 meter.
 * c.setUnit(Unit.MILE_NAUTICAL);                              // Switching to nautical miles.
 * System.out.println("Nautical miles: " + c.getLength());     // Printing 1852 meter in nautical miles.
 *
 * System.out.println("\nTurning imperial miles into inches");
 * c.setUnit(Unit.MILE_IMPERIAL);
 * c.setLength(2.0);                                           // Two terrestrial miles.
 * c.setUnit(Unit.INCH);                                       // Switching unit to inch.
 * System.out.println("Inches: " + c.getLength());             // Printing 2 terrestrial miles in inches.</code></pre>
 *             </td>
 *             <td>
 *                 <pre><code class="nohighlight">Turning meter into nautical miles
 * Nautical miles: 1.0
 *
 * Turning imperial miles into inches
 * Inches: 126720.0</code></pre>
 *             </td>
 *         </tr>
 *     </tbody>
 * </table>
 *
 * <p>You may as well start from a non-meter unit:</p>
 *
 * <table class="goikTableDefaults">
 *     <caption>Sample code starting from inch default unit.</caption>
 *     <tbody>
 *         <tr>
 *             <th>Code</th>
 *             <th>Result</th>
 *         </tr>
 *         <tr>
 *             <td>
 *                 <pre><code class="java"> final LengthUnitCalculator c = new LengthUnitCalculator(Unit.INCH); // Default unit inch.
 *
 * System.out.println("Turning inches into meter");
 * c.setLength(1);                                                     // Default unit still inch
 * c.setUnit(Unit.METER);                                              // Switching from inch to meter
 * System.out.println("meter: " + c.getLength());                      // Printing 1 inch in meter.</code></pre>
 *             </td>
 *             <td>
 *                 <pre><code class="nohighlight">Turning inches into meter
 * meter: 0.0254</code></pre>
 *             </td>
 *         </tr>
 *     </tbody>
 * </table>
 *
 * <section class="implementationHints">
 *    <h2>Hint:</h2>
 *
 *    <ul>
 *        <li>This class is yet unimplemented. The above code snippets provide a clue to an implementation
 *        satisfying the corresponding unit tests.</li>
 *        <li>You may extend enum class {@link Unit} to suit your needs. The individual enum definitions
 *        might be a good place for storing conversion factors like e.g. 1852.0.</li>
 *    </ul>
 *
 * </section>
 */
public class LengthUnitCalculator {

    double length;
    Unit unit = null;
    void setLength(final double length) {
        this.length = length;
    }

    void setUnit(final Unit unit ) {
        if (null != unit) {

        }

        this.unit = unit;
    }


}
